@@ -3,6 +3,8 @@ from __future__ import absolute_import
 # flake8: noqa
 
 # import apis into api package
+from seldon_deploy_sdk.api.alerting_service_api import AlertingServiceApi
+from seldon_deploy_sdk.api.application_logs_api import ApplicationLogsApi
 from seldon_deploy_sdk.api.batch_jobs_api import BatchJobsApi
 from seldon_deploy_sdk.api.drift_detector_api import DriftDetectorApi
 from seldon_deploy_sdk.api.environment_api import EnvironmentApi
@@ -13,6 +15,8 @@ from seldon_deploy_sdk.api.kubernetes_resources_api import KubernetesResourcesAp
 from seldon_deploy_sdk.api.loadtest_jobs_api import LoadtestJobsApi
 from seldon_deploy_sdk.api.metrics_server_api import MetricsServerApi
 from seldon_deploy_sdk.api.model_metadata_service_api import ModelMetadataServiceApi
+from seldon_deploy_sdk.api.monitor_api import MonitorApi
 from seldon_deploy_sdk.api.outlier_detector_api import OutlierDetectorApi
+from seldon_deploy_sdk.api.permission_management_service_api import PermissionManagementServiceApi
 from seldon_deploy_sdk.api.predict_api import PredictApi
 from seldon_deploy_sdk.api.seldon_deployments_api import SeldonDeploymentsApi
